import os

def whoAmI():
    try:
        username = os.getenv('USERNAME')
        
        if username:
            return username
        else:
            raise Exception('It was not possible to determine the user.')
    
    except Exception as e:
        raise Exception(f"Error getting username: {str(e)}")


import time

def dummy_send(driver, xpath, word, delay):    
    for c in word:
        driver.find_element('xpath',xpath).send_keys(c)
        time.sleep(delay)

def element_exists(driver, xpath, timeout):
    start_time = time.time()

    while time.time() - start_time < timeout:
        try:
            driver.find_element('xpath', xpath)
            return True
        except Exception as e:
            time.sleep(1)

    return False